@@ -25,9 +25,10 @@ C*****repcom.txt
 c      COMMON/REPCOM/PRPI,REQSW,VOB,KFSW
       COMMON/REPCOM/VOB,REQSW,KFSW,PRPI	
 C*****kfasav.txt
-      REAL PRE(500),PRV(500),FSER(500),FVAR(500),SSER(500),SVAR(500)
-      DOUBLE PRECISION FSES(500,20),FSCV(500,20,20),SSES(500,20)
-     1,SSCV(500,20,20),PSES(500,20),PSCV(500,20,20),TRAN(500,20,20)
+      REAL PRE(5000),PRV(5000),FSER(5000),FVAR(5000),SSER(5000)
+     1,SVAR(5000)
+      DOUBLE PRECISION FSES(5000,20),FSCV(5000,20,20),SSES(5000,20)
+     1,SSCV(5000,20,20),PSES(5000,20),PSCV(5000,20,20),TRAN(5000,20,20)
 c      COMMON/KFASAV/PRE,PRV,FSER,FVAR,SSER,SVAR,FSES,FSCV,SSES,SSCV
 c     1,PSES,PSCV,TRAN
       COMMON/KFASAV/FSES,FSCV,SSES,SSCV
@@ -42,12 +43,12 @@ c     *GMOLD,GMNEW,SIGSQ,OLDB
      *GMOLD,GMNEW,SIGSQ,OLDB,CONV,FAIL,NP,ITCT,PPIND
 C*****veccom.txt
       DOUBLE PRECISION B(22),NEWB(22),PERB(22),DELB(22),
-     * ERR(500),RES(500),PRES(22,500),sres(500)
+     * ERR(5000),RES(5000),PRES(22,5000),sres(5000)
       COMMON/VECCOM/B,NEWB,PERB,DELB,ERR,RES,PRES,sres
 C*****series.txt
       CHARACTER*40 NAME
       INTEGER LEN
-      DOUBLE PRECISION TIM(500),SER(500),TDIF(500)
+      DOUBLE PRECISION TIM(5000),SER(5000),TDIF(5000)
 c      COMMON/SERIES/NAME,LEN,TIM,SER,TDIF
       COMMON/SERIES/TIM,SER,TDIF,NAME,LEN
 C*****repar3.txt
